@@ -85,7 +85,7 @@ except ImportError:
 
 from importlib import reload
 
-from pyfakefs import fake_filesystem
+from pyfakefs import fake_filesystem, fake_io, fake_os, fake_open, fake_path, fake_file
 from pyfakefs import fake_filesystem_shutil
 from pyfakefs import fake_pathlib
 from pyfakefs import mox3_stubout
@@ -444,6 +444,11 @@ class Patcher:
         None,
         fake_filesystem,
         fake_filesystem_shutil,
+        fake_os,
+        fake_io,
+        fake_open,
+        fake_path,
+        fake_file,
         sys,
         linecache,
         tokenize,
@@ -640,15 +645,17 @@ class Patcher:
         # and a test in fake_filesystem_unittest_test.py, class
         # TestAttributesWithFakeModuleNames.
         self._fake_module_classes = {
-            "os": fake_filesystem.FakeOsModule,
+            "os": fake_os.FakeOsModule,
             "shutil": fake_filesystem_shutil.FakeShutilModule,
-            "io": fake_filesystem.FakeIoModule,
+            "io": fake_io.FakeIoModule,
             "pathlib": fake_pathlib.FakePathlibModule,
         }
         if IS_PYPY:
             # in PyPy io.open, the module is referenced as _io
-            self._fake_module_classes["_io"] = fake_filesystem.FakeIoModule
-        if sys.platform != "win32":
+            self._fake_module_classes["_io"] = fake_io.FakeIoModule
+        if sys.platform == "win32":
+            self._fake_module_classes["nt"] = fake_path.FakeNtModule
+        else:
             self._fake_module_classes["fcntl"] = fake_filesystem.FakeFcntlModule
 
         # class modules maps class names against a list of modules they can
@@ -884,10 +891,16 @@ class Patcher:
         linecache.open = self.original_open  # type: ignore[attr-defined]
         tokenize._builtin_open = self.original_open  # type: ignore
 
-        # the temp directory is assumed to exist at least in `tempfile1`,
+        # the temp directory is assumed to exist at least in `tempfile`,
         # so we create it here for convenience
         assert self.fs is not None
         self.fs.create_dir(temp_dir)
+        if sys.platform != "win32" and not self.fs.exists("/tmp"):
+            # under Posix, we also create a link in /tmp if the path does not exist
+            self.fs.create_symlink("/tmp", temp_dir)
+            # reset the used size to 0 to avoid having the link size counted
+            # which would make disk size tests more complicated
+            next(iter(self.fs.mount_points.values()))["used_size"] = 0
 
     def start_patching(self) -> None:
         if not self._patching:
@@ -923,7 +936,7 @@ class Patcher:
                     self._stubs.smart_set(module, name, self.unfaked_modules[attr])
 
     def patch_defaults(self) -> None:
-        for (fct, idx, ft) in self.FS_DEFARGS:
+        for fct, idx, ft in self.FS_DEFARGS:
             method, mod_name = self._fake_module_functions[ft.__name__][ft.__module__]
             fake_module = self.fake_modules[mod_name]
             attr = method.__get__(fake_module, fake_module.__class__)
@@ -977,7 +990,7 @@ class Patcher:
                 sys.meta_path.pop(0)
 
     def unset_defaults(self) -> None:
-        for (fct, idx, ft) in self.FS_DEFARGS:
+        for fct, idx, ft in self.FS_DEFARGS:
             new_defaults = []
             for i, d in enumerate(cast(Tuple, fct.__defaults__)):
                 if i == idx:
