@@ -44,19 +44,25 @@ from urllib.parse import quote_from_bytes as urlquote_from_bytes
 
 from pyfakefs import fake_scandir
 from pyfakefs.extra_packages import use_scandir
-from pyfakefs.fake_filesystem import (
-    FakeFileOpen,
-    FakeFilesystem,
-    use_original_os,
-)
+from pyfakefs.fake_filesystem import FakeFilesystem
+from pyfakefs.fake_open import FakeFileOpen
+from pyfakefs.fake_os import FakeOsModule, use_original_os
 
 
 def init_module(filesystem):
     """Initializes the fake module with the fake file system."""
     # pylint: disable=protected-access
     FakePath.filesystem = filesystem
-    FakePathlibModule.PureWindowsPath._flavour = _FakeWindowsFlavour(filesystem)
-    FakePathlibModule.PurePosixPath._flavour = _FakePosixFlavour(filesystem)
+    if sys.version_info < (3, 12):
+        FakePathlibModule.PureWindowsPath._flavour = _FakeWindowsFlavour(filesystem)
+        FakePathlibModule.PurePosixPath._flavour = _FakePosixFlavour(filesystem)
+    else:
+        # in Python 3.12, the flavour is no longer an own class,
+        # but points to the os-specific path module (posixpath/ntpath)
+        fake_os = FakeOsModule(filesystem)
+        fake_path = fake_os.path
+        FakePathlibModule.PureWindowsPath._flavour = fake_path
+        FakePathlibModule.PurePosixPath._flavour = fake_path
 
 
 def _wrap_strfunc(strfunc):
@@ -126,7 +132,7 @@ class _FakeAccessor(accessor):  # type: ignore [valid-type, misc]
 
             if (
                 not kwargs["follow_symlinks"]
-                and os.os_module.chmod not in os.supports_follow_symlinks
+                and os.os_module.chmod not in os.os_module.supports_follow_symlinks
             ):
                 raise NotImplementedError(
                     "`follow_symlinks` for chmod() is not available " "on this system"
@@ -178,322 +184,322 @@ class _FakeAccessor(accessor):  # type: ignore [valid-type, misc]
 
 _fake_accessor = _FakeAccessor()
 
-flavour = pathlib._Flavour  # type: ignore [attr-defined]
+if sys.version_info < (3, 12):
+    flavour = pathlib._Flavour  # type: ignore [attr-defined]
 
+    class _FakeFlavour(flavour):  # type: ignore [valid-type, misc]
+        """Fake Flavour implementation used by PurePath and _Flavour"""
 
-class _FakeFlavour(flavour):  # type: ignore [valid-type, misc]
-    """Fake Flavour implementation used by PurePath and _Flavour"""
+        filesystem = None
+        sep = "/"
+        altsep = None
+        has_drv = False
 
-    filesystem = None
-    sep = "/"
-    altsep = None
-    has_drv = False
+        ext_namespace_prefix = "\\\\?\\"
 
-    ext_namespace_prefix = "\\\\?\\"
+        drive_letters = {chr(x) for x in range(ord("a"), ord("z") + 1)} | {
+            chr(x) for x in range(ord("A"), ord("Z") + 1)
+        }
 
-    drive_letters = {chr(x) for x in range(ord("a"), ord("z") + 1)} | {
-        chr(x) for x in range(ord("A"), ord("Z") + 1)
-    }
+        def __init__(self, filesystem):
+            self.filesystem = filesystem
+            self.sep = filesystem.path_separator
+            self.altsep = filesystem.alternative_path_separator
+            self.has_drv = filesystem.is_windows_fs
+            super(_FakeFlavour, self).__init__()
 
-    def __init__(self, filesystem):
-        self.filesystem = filesystem
-        self.sep = filesystem.path_separator
-        self.altsep = filesystem.alternative_path_separator
-        self.has_drv = filesystem.is_windows_fs
-        super(_FakeFlavour, self).__init__()
+        @staticmethod
+        def _split_extended_path(path, ext_prefix=ext_namespace_prefix):
+            prefix = ""
+            if path.startswith(ext_prefix):
+                prefix = path[:4]
+                path = path[4:]
+                if path.startswith("UNC\\"):
+                    prefix += path[:3]
+                    path = "\\" + path[3:]
+            return prefix, path
 
-    @staticmethod
-    def _split_extended_path(path, ext_prefix=ext_namespace_prefix):
-        prefix = ""
-        if path.startswith(ext_prefix):
-            prefix = path[:4]
-            path = path[4:]
-            if path.startswith("UNC\\"):
-                prefix += path[:3]
-                path = "\\" + path[3:]
-        return prefix, path
-
-    def _splitroot_with_drive(self, path, sep):
-        first = path[0:1]
-        second = path[1:2]
-        if second == sep and first == sep:
-            # extended paths should also disable the collapsing of "."
-            # components (according to MSDN docs).
-            prefix, path = self._split_extended_path(path)
+        def _splitroot_with_drive(self, path, sep):
             first = path[0:1]
             second = path[1:2]
-        else:
-            prefix = ""
-        third = path[2:3]
-        if second == sep and first == sep and third != sep:
-            # is a UNC path:
-            # vvvvvvvvvvvvvvvvvvvvv root
-            # \\machine\mountpoint\directory\etc\...
-            #            directory ^^^^^^^^^^^^^^
-            index = path.find(sep, 2)
-            if index != -1:
-                index2 = path.find(sep, index + 1)
-                # a UNC path can't have two slashes in a row
-                # (after the initial two)
-                if index2 != index + 1:
-                    if index2 == -1:
-                        index2 = len(path)
-                    if prefix:
-                        return prefix + path[1:index2], sep, path[index2 + 1 :]
-                    return path[:index2], sep, path[index2 + 1 :]
-        drv = root = ""
-        if second == ":" and first in self.drive_letters:
-            drv = path[:2]
-            path = path[2:]
-            first = third
-        if first == sep:
-            root = first
-            path = path.lstrip(sep)
-        return prefix + drv, root, path
+            if second == sep and first == sep:
+                # extended paths should also disable the collapsing of "."
+                # components (according to MSDN docs).
+                prefix, path = self._split_extended_path(path)
+                first = path[0:1]
+                second = path[1:2]
+            else:
+                prefix = ""
+            third = path[2:3]
+            if second == sep and first == sep and third != sep:
+                # is a UNC path:
+                # vvvvvvvvvvvvvvvvvvvvv root
+                # \\machine\mountpoint\directory\etc\...
+                #            directory ^^^^^^^^^^^^^^
+                index = path.find(sep, 2)
+                if index != -1:
+                    index2 = path.find(sep, index + 1)
+                    # a UNC path can't have two slashes in a row
+                    # (after the initial two)
+                    if index2 != index + 1:
+                        if index2 == -1:
+                            index2 = len(path)
+                        if prefix:
+                            return prefix + path[1:index2], sep, path[index2 + 1 :]
+                        return path[:index2], sep, path[index2 + 1 :]
+            drv = root = ""
+            if second == ":" and first in self.drive_letters:
+                drv = path[:2]
+                path = path[2:]
+                first = third
+            if first == sep:
+                root = first
+                path = path.lstrip(sep)
+            return prefix + drv, root, path
 
-    @staticmethod
-    def _splitroot_posix(path, sep):
-        if path and path[0] == sep:
-            stripped_part = path.lstrip(sep)
-            if len(path) - len(stripped_part) == 2:
-                return "", sep * 2, stripped_part
-            return "", sep, stripped_part
-        else:
-            return "", "", path
+        @staticmethod
+        def _splitroot_posix(path, sep):
+            if path and path[0] == sep:
+                stripped_part = path.lstrip(sep)
+                if len(path) - len(stripped_part) == 2:
+                    return "", sep * 2, stripped_part
+                return "", sep, stripped_part
+            else:
+                return "", "", path
 
-    def splitroot(self, path, sep=None):
-        """Split path into drive, root and rest."""
-        if sep is None:
-            sep = self.filesystem.path_separator
-        if self.filesystem.is_windows_fs:
-            return self._splitroot_with_drive(path, sep)
-        return self._splitroot_posix(path, sep)
-
-    def casefold(self, path):
-        """Return the lower-case version of s for a Windows filesystem."""
-        if self.filesystem.is_windows_fs:
-            return path.lower()
-        return path
-
-    def casefold_parts(self, parts):
-        """Return the lower-case version of parts for a Windows filesystem."""
-        if self.filesystem.is_windows_fs:
-            return [p.lower() for p in parts]
-        return parts
-
-    def _resolve_posix(self, path, strict):
-        sep = self.sep
-        seen = {}
-
-        def _resolve(path, rest):
-            if rest.startswith(sep):
-                path = ""
-
-            for name in rest.split(sep):
-                if not name or name == ".":
-                    # current dir
-                    continue
-                if name == "..":
-                    # parent dir
-                    path, _, _ = path.rpartition(sep)
-                    continue
-                newpath = path + sep + name
-                if newpath in seen:
-                    # Already seen this path
-                    path = seen[newpath]
-                    if path is not None:
-                        # use cached value
-                        continue
-                    # The symlink is not resolved, so we must have
-                    # a symlink loop.
-                    raise RuntimeError("Symlink loop from %r" % newpath)
-                # Resolve the symbolic link
-                try:
-                    target = self.filesystem.readlink(newpath)
-                except OSError as e:
-                    if e.errno != errno.EINVAL and strict:
-                        raise
-                    # Not a symlink, or non-strict mode. We just leave the path
-                    # untouched.
-                    path = newpath
-                else:
-                    seen[newpath] = None  # not resolved symlink
-                    path = _resolve(path, target)
-                    seen[newpath] = path  # resolved symlink
+        def splitroot(self, path, sep=None):
+            """Split path into drive, root and rest."""
+            if sep is None:
+                sep = self.filesystem.path_separator
+            if self.filesystem.is_windows_fs:
+                return self._splitroot_with_drive(path, sep)
+            return self._splitroot_posix(path, sep)
 
+        def casefold(self, path):
+            """Return the lower-case version of s for a Windows filesystem."""
+            if self.filesystem.is_windows_fs:
+                return path.lower()
             return path
 
-        # NOTE: according to POSIX, getcwd() cannot contain path components
-        # which are symlinks.
-        base = "" if path.is_absolute() else self.filesystem.cwd
-        return _resolve(base, str(path)) or sep
+        def casefold_parts(self, parts):
+            """Return the lower-case version of parts for a Windows filesystem."""
+            if self.filesystem.is_windows_fs:
+                return [p.lower() for p in parts]
+            return parts
 
-    def _resolve_windows(self, path, strict):
-        path = str(path)
-        if not path:
-            return os.getcwd()
-        previous_s = None
-        if strict:
-            if not self.filesystem.exists(path):
-                self.filesystem.raise_os_error(errno.ENOENT, path)
-            return self.filesystem.resolve_path(path)
-        else:
-            while True:
+        def _resolve_posix(self, path, strict):
+            sep = self.sep
+            seen = {}
+
+            def _resolve(path, rest):
+                if rest.startswith(sep):
+                    path = ""
+
+                for name in rest.split(sep):
+                    if not name or name == ".":
+                        # current dir
+                        continue
+                    if name == "..":
+                        # parent dir
+                        path, _, _ = path.rpartition(sep)
+                        continue
+                    newpath = path + sep + name
+                    if newpath in seen:
+                        # Already seen this path
+                        path = seen[newpath]
+                        if path is not None:
+                            # use cached value
+                            continue
+                        # The symlink is not resolved, so we must have
+                        # a symlink loop.
+                        raise RuntimeError("Symlink loop from %r" % newpath)
+                    # Resolve the symbolic link
+                    try:
+                        target = self.filesystem.readlink(newpath)
+                    except OSError as e:
+                        if e.errno != errno.EINVAL and strict:
+                            raise
+                        # Not a symlink, or non-strict mode. We just leave the path
+                        # untouched.
+                        path = newpath
+                    else:
+                        seen[newpath] = None  # not resolved symlink
+                        path = _resolve(path, target)
+                        seen[newpath] = path  # resolved symlink
+
+                return path
+
+            # NOTE: according to POSIX, getcwd() cannot contain path components
+            # which are symlinks.
+            base = "" if path.is_absolute() else self.filesystem.cwd
+            return _resolve(base, str(path)) or sep
+
+        def _resolve_windows(self, path, strict):
+            path = str(path)
+            if not path:
+                return os.getcwd()
+            previous_s = None
+            if strict:
+                if not self.filesystem.exists(path):
+                    self.filesystem.raise_os_error(errno.ENOENT, path)
+                return self.filesystem.resolve_path(path)
+            else:
+                while True:
+                    try:
+                        path = self.filesystem.resolve_path(path)
+                    except OSError:
+                        previous_s = path
+                        path = self.filesystem.splitpath(path)[0]
+                    else:
+                        if previous_s is None:
+                            return path
+                        return self.filesystem.joinpaths(
+                            path, os.path.basename(previous_s)
+                        )
+
+        def resolve(self, path, strict):
+            """Make the path absolute, resolving any symlinks."""
+            if self.filesystem.is_windows_fs:
+                return self._resolve_windows(path, strict)
+            return self._resolve_posix(path, strict)
+
+        def gethomedir(self, username):
+            """Return the home directory of the current user."""
+            if not username:
                 try:
-                    path = self.filesystem.resolve_path(path)
-                except OSError:
-                    previous_s = path
-                    path = self.filesystem.splitpath(path)[0]
-                else:
-                    if previous_s is None:
-                        return path
-                    return self.filesystem.joinpaths(path, os.path.basename(previous_s))
+                    return os.environ["HOME"]
+                except KeyError:
+                    import pwd
 
-    def resolve(self, path, strict):
-        """Make the path absolute, resolving any symlinks."""
-        if self.filesystem.is_windows_fs:
-            return self._resolve_windows(path, strict)
-        return self._resolve_posix(path, strict)
-
-    def gethomedir(self, username):
-        """Return the home directory of the current user."""
-        if not username:
-            try:
-                return os.environ["HOME"]
-            except KeyError:
+                    return pwd.getpwuid(os.getuid()).pw_dir
+            else:
                 import pwd
 
-                return pwd.getpwuid(os.getuid()).pw_dir
-        else:
-            import pwd
-
-            try:
-                return pwd.getpwnam(username).pw_dir
-            except KeyError:
-                raise RuntimeError(
-                    "Can't determine home directory " "for %r" % username
-                )
-
-
-class _FakeWindowsFlavour(_FakeFlavour):
-    """Flavour used by PureWindowsPath with some Windows specific
-    implementations independent of FakeFilesystem properties.
-    """
-
-    reserved_names = (
-        {"CON", "PRN", "AUX", "NUL"}
-        | {"COM%d" % i for i in range(1, 10)}
-        | {"LPT%d" % i for i in range(1, 10)}
-    )
-    pathmod = ntpath
-
-    def is_reserved(self, parts):
-        """Return True if the path is considered reserved under Windows."""
-
-        # NOTE: the rules for reserved names seem somewhat complicated
-        # (e.g. r"..\NUL" is reserved but not r"foo\NUL").
-        # We err on the side of caution and return True for paths which are
-        # not considered reserved by Windows.
-        if not parts:
-            return False
-        if self.filesystem.is_windows_fs and parts[0].startswith("\\\\"):
-            # UNC paths are never reserved
-            return False
-        return parts[-1].partition(".")[0].upper() in self.reserved_names
-
-    def make_uri(self, path):
-        """Return a file URI for the given path"""
-
-        # Under Windows, file URIs use the UTF-8 encoding.
-        # original version, not faked
-        drive = path.drive
-        if len(drive) == 2 and drive[1] == ":":
-            # It's a path on a local drive => 'file:///c:/a/b'
-            rest = path.as_posix()[2:].lstrip("/")
-            return "file:///%s/%s" % (
-                drive,
-                urlquote_from_bytes(rest.encode("utf-8")),
-            )
-        else:
-            # It's a path on a network drive => 'file://host/share/a/b'
-            return "file:" + urlquote_from_bytes(path.as_posix().encode("utf-8"))
-
-    def gethomedir(self, username):
-        """Return the home directory of the current user."""
-
-        # original version, not faked
-        if "HOME" in os.environ:
-            userhome = os.environ["HOME"]
-        elif "USERPROFILE" in os.environ:
-            userhome = os.environ["USERPROFILE"]
-        elif "HOMEPATH" in os.environ:
-            try:
-                drv = os.environ["HOMEDRIVE"]
-            except KeyError:
-                drv = ""
-            userhome = drv + os.environ["HOMEPATH"]
-        else:
-            raise RuntimeError("Can't determine home directory")
-
-        if username:
-            # Try to guess user home directory.  By default all users
-            # directories are located in the same place and are named by
-            # corresponding usernames.  If current user home directory points
-            # to nonstandard place, this guess is likely wrong.
-            if os.environ["USERNAME"] != username:
-                drv, root, parts = self.parse_parts((userhome,))
-                if parts[-1] != os.environ["USERNAME"]:
+                try:
+                    return pwd.getpwnam(username).pw_dir
+                except KeyError:
                     raise RuntimeError(
                         "Can't determine home directory " "for %r" % username
                     )
-                parts[-1] = username
-                if drv or root:
-                    userhome = drv + root + self.join(parts[1:])
-                else:
-                    userhome = self.join(parts)
-        return userhome
 
-    def compile_pattern(self, pattern):
-        return re.compile(fnmatch.translate(pattern), re.IGNORECASE).fullmatch
+    class _FakeWindowsFlavour(_FakeFlavour):
+        """Flavour used by PureWindowsPath with some Windows specific
+        implementations independent of FakeFilesystem properties.
+        """
 
+        reserved_names = (
+            {"CON", "PRN", "AUX", "NUL"}
+            | {"COM%d" % i for i in range(1, 10)}
+            | {"LPT%d" % i for i in range(1, 10)}
+        )
+        pathmod = ntpath
 
-class _FakePosixFlavour(_FakeFlavour):
-    """Flavour used by PurePosixPath with some Unix specific implementations
-    independent of FakeFilesystem properties.
-    """
+        def is_reserved(self, parts):
+            """Return True if the path is considered reserved under Windows."""
 
-    pathmod = posixpath
+            # NOTE: the rules for reserved names seem somewhat complicated
+            # (e.g. r"..\NUL" is reserved but not r"foo\NUL").
+            # We err on the side of caution and return True for paths which are
+            # not considered reserved by Windows.
+            if not parts:
+                return False
+            if self.filesystem.is_windows_fs and parts[0].startswith("\\\\"):
+                # UNC paths are never reserved
+                return False
+            return parts[-1].partition(".")[0].upper() in self.reserved_names
 
-    def is_reserved(self, parts):
-        return False
+        def make_uri(self, path):
+            """Return a file URI for the given path"""
 
-    def make_uri(self, path):
-        # We represent the path using the local filesystem encoding,
-        # for portability to other applications.
-        bpath = bytes(path)
-        return "file://" + urlquote_from_bytes(bpath)
+            # Under Windows, file URIs use the UTF-8 encoding.
+            # original version, not faked
+            drive = path.drive
+            if len(drive) == 2 and drive[1] == ":":
+                # It's a path on a local drive => 'file:///c:/a/b'
+                rest = path.as_posix()[2:].lstrip("/")
+                return "file:///%s/%s" % (
+                    drive,
+                    urlquote_from_bytes(rest.encode("utf-8")),
+                )
+            else:
+                # It's a path on a network drive => 'file://host/share/a/b'
+                return "file:" + urlquote_from_bytes(path.as_posix().encode("utf-8"))
 
-    def gethomedir(self, username):
-        # original version, not faked
-        if not username:
-            try:
-                return os.environ["HOME"]
-            except KeyError:
+        def gethomedir(self, username):
+            """Return the home directory of the current user."""
+
+            # original version, not faked
+            if "HOME" in os.environ:
+                userhome = os.environ["HOME"]
+            elif "USERPROFILE" in os.environ:
+                userhome = os.environ["USERPROFILE"]
+            elif "HOMEPATH" in os.environ:
+                try:
+                    drv = os.environ["HOMEDRIVE"]
+                except KeyError:
+                    drv = ""
+                userhome = drv + os.environ["HOMEPATH"]
+            else:
+                raise RuntimeError("Can't determine home directory")
+
+            if username:
+                # Try to guess user home directory.  By default all users
+                # directories are located in the same place and are named by
+                # corresponding usernames.  If current user home directory points
+                # to nonstandard place, this guess is likely wrong.
+                if os.environ["USERNAME"] != username:
+                    drv, root, parts = self.parse_parts((userhome,))
+                    if parts[-1] != os.environ["USERNAME"]:
+                        raise RuntimeError(
+                            "Can't determine home directory " "for %r" % username
+                        )
+                    parts[-1] = username
+                    if drv or root:
+                        userhome = drv + root + self.join(parts[1:])
+                    else:
+                        userhome = self.join(parts)
+            return userhome
+
+        def compile_pattern(self, pattern):
+            return re.compile(fnmatch.translate(pattern), re.IGNORECASE).fullmatch
+
+    class _FakePosixFlavour(_FakeFlavour):
+        """Flavour used by PurePosixPath with some Unix specific implementations
+        independent of FakeFilesystem properties.
+        """
+
+        pathmod = posixpath
+
+        def is_reserved(self, parts):
+            return False
+
+        def make_uri(self, path):
+            # We represent the path using the local filesystem encoding,
+            # for portability to other applications.
+            bpath = bytes(path)
+            return "file://" + urlquote_from_bytes(bpath)
+
+        def gethomedir(self, username):
+            # original version, not faked
+            if not username:
+                try:
+                    return os.environ["HOME"]
+                except KeyError:
+                    import pwd
+
+                    return pwd.getpwuid(os.getuid()).pw_dir
+            else:
                 import pwd
 
-                return pwd.getpwuid(os.getuid()).pw_dir
-        else:
-            import pwd
+                try:
+                    return pwd.getpwnam(username).pw_dir
+                except KeyError:
+                    raise RuntimeError(
+                        "Can't determine home directory " "for %r" % username
+                    )
 
-            try:
-                return pwd.getpwnam(username).pw_dir
-            except KeyError:
-                raise RuntimeError(
-                    "Can't determine home directory " "for %r" % username
-                )
-
-    def compile_pattern(self, pattern):
-        return re.compile(fnmatch.translate(pattern)).fullmatch
+        def compile_pattern(self, pattern):
+            return re.compile(fnmatch.translate(pattern)).fullmatch
 
 
 class FakePath(pathlib.Path):
@@ -514,36 +520,41 @@ class FakePath(pathlib.Path):
                 if cls.filesystem.is_windows_fs
                 else FakePathlibModule.PosixPath
             )
-        self = cls._from_parts(args)
-        return self
+        if sys.version_info < (3, 12):
+            return cls._from_parts(args)
+        else:
+            return object.__new__(cls)
 
-    @classmethod
-    def _from_parts(cls, args, init=False):  # pylint: disable=unused-argument
-        # Overwritten to call _init to set the fake accessor,
-        # which is not done since Python 3.10
-        self = object.__new__(cls)
-        self._init()
-        drv, root, parts = self._parse_args(args)
-        self._drv = drv
-        self._root = root
-        self._parts = parts
-        return self
+    if sys.version_info[:2] == (3, 10):
+        # Overwritten class methods to call _init to set the fake accessor,
+        # which is not done in Python 3.10, and not needed from Python 3.11 on
+        @classmethod
+        def _from_parts(cls, args, init=False):  # pylint: disable=unused-argument
+            self = object.__new__(cls)
+            self._init()
+            drv, root, parts = self._parse_args(args)
+            self._drv = drv
+            self._root = root
+            self._parts = parts
+            return self
 
-    @classmethod
-    def _from_parsed_parts(cls, drv, root, parts):
-        # Overwritten to call _init to set the fake accessor,
-        # which is not done since Python 3.10
-        self = object.__new__(cls)
-        self._init()
-        self._drv = drv
-        self._root = root
-        self._parts = parts
-        return self
+        @classmethod
+        def _from_parsed_parts(cls, drv, root, parts):
+            self = object.__new__(cls)
+            self._drv = drv
+            self._root = root
+            self._parts = parts
+            self._init()
+            return self
 
-    def _init(self, template=None):
-        """Initializer called from base class."""
-        self._accessor = _fake_accessor
-        self._closed = False
+    if sys.version_info < (3, 11):
+
+        def _init(self, template=None):
+            """Initializer called from base class."""
+            # only needed until Python 3.10
+            self._accessor = _fake_accessor
+            # only needed until Python 3.8
+            self._closed = False
 
     def _path(self):
         """Returns the underlying path string as used by the fake
@@ -558,34 +569,37 @@ class FakePath(pathlib.Path):
         """
         return cls(cls.filesystem.cwd)
 
-    def resolve(self, strict=None):
-        """Make the path absolute, resolving all symlinks on the way and also
-        normalizing it (for example turning slashes into backslashes
-        under Windows).
+    if sys.version_info < (3, 12):  # in 3.12, we can use the pathlib implementation
 
-        Args:
-            strict: If False (default) no exception is raised if the path
-                does not exist.
-                New in Python 3.6.
+        def resolve(self, strict=None):
+            """Make the path absolute, resolving all symlinks on the way and also
+            normalizing it (for example turning slashes into backslashes
+            under Windows).
 
-        Raises:
-            OSError: if the path doesn't exist (strict=True or Python < 3.6)
-        """
-        if sys.version_info >= (3, 6):
-            if strict is None:
-                strict = False
-        else:
-            if strict is not None:
-                raise TypeError("resolve() got an unexpected keyword argument 'strict'")
-            strict = True
-        if self._closed:
-            self._raise_closed()
-        path = self._flavour.resolve(self, strict=strict)
-        if path is None:
-            self.stat()
-            path = str(self.absolute())
-        path = self.filesystem.absnormpath(path)
-        return FakePath(path)
+            Args:
+                strict: If False (default) no exception is raised if the path
+                    does not exist.
+                    New in Python 3.6.
+
+            Raises:
+                OSError: if the path doesn't exist (strict=True or Python < 3.6)
+            """
+            if sys.version_info >= (3, 6):
+                if strict is None:
+                    strict = False
+            else:
+                if strict is not None:
+                    raise TypeError(
+                        "resolve() got an unexpected keyword argument 'strict'"
+                    )
+                strict = True
+            self._raise_on_closed()
+            path = self._flavour.resolve(self, strict=strict)
+            if path is None:
+                self.stat()
+                path = str(self.absolute())
+            path = self.filesystem.absnormpath(path)
+            return FakePath(path)
 
     def open(self, mode="r", buffering=-1, encoding=None, errors=None, newline=None):
         """Open the file pointed by this path and return a fake file object.
@@ -594,8 +608,7 @@ class FakePath(pathlib.Path):
             OSError: if the target object is a directory, the path is invalid
                 or permission is denied.
         """
-        if self._closed:
-            self._raise_closed()
+        self._raise_on_closed()
         return FakeFileOpen(self.filesystem)(
             self._path(), mode, buffering, encoding, errors, newline
         )
@@ -707,6 +720,10 @@ class FakePath(pathlib.Path):
             )
         )
 
+    def _raise_on_closed(self):
+        if sys.version_info < (3, 9) and self._closed:
+            self._raise_closed()
+
     def touch(self, mode=0o666, exist_ok=True):
         """Create a fake file for the path with the given access mode,
         if it doesn't exist.
@@ -719,8 +736,7 @@ class FakePath(pathlib.Path):
         Raises:
             FileExistsError: if the file exists and exits_ok is False.
         """
-        if self._closed:
-            self._raise_closed()
+        self._raise_on_closed()
         if self.exists():
             if exist_ok:
                 self.filesystem.utime(self._path(), times=None)
@@ -731,6 +747,25 @@ class FakePath(pathlib.Path):
             fake_file.close()
             self.chmod(mode)
 
+    if sys.version_info >= (3, 12):
+        """These are reimplemented for now because the original implementation
+        checks the flavour against ntpath/posixpath.
+        """
+
+        def is_absolute(self):
+            if self.filesystem.is_windows_fs:
+                return self.drive and self.root
+            return os.path.isabs(self._path())
+
+        def is_reserved(self):
+            if not self.filesystem.is_windows_fs or not self._parts:
+                return False
+            if self._parts[0].startswith("\\\\"):
+                # UNC paths are never reserved.
+                return False
+            name = self._parts[-1].partition(".")[0].partition(":")[0].rstrip(" ")
+            return name.upper() in pathlib._WIN_RESERVED_NAMES
+
 
 class FakePathlibModule:
     """Uses FakeFilesystem to provide a fake pathlib module replacement.
@@ -838,11 +873,14 @@ class RealPath(pathlib.Path):
     itself is not.
     """
 
-    _flavour = (
-        pathlib._WindowsFlavour()  # type:ignore
-        if os.name == "nt"
-        else pathlib._PosixFlavour()  # type:ignore
-    )  # type:ignore
+    if sys.version_info < (3, 12):
+        _flavour = (
+            pathlib._WindowsFlavour()  # type:ignore
+            if os.name == "nt"
+            else pathlib._PosixFlavour()  # type:ignore
+        )  # type:ignore
+    else:
+        _flavour = ntpath if os.name == "nt" else posixpath
 
     def __new__(cls, *args, **kwargs):
         """Creates the correct subclass based on OS."""
@@ -852,8 +890,10 @@ class RealPath(pathlib.Path):
                 if os.name == "nt"
                 else RealPathlibModule.PosixPath
             )
-        self = cls._from_parts(args)
-        return self
+        if sys.version_info < (3, 12):
+            return cls._from_parts(args)
+        else:
+            return object.__new__(cls)
 
 
 if sys.version_info > (3, 10):
