@@ -28,9 +28,9 @@ import unittest
 from collections import namedtuple
 from unittest import mock
 
-from pyfakefs import fake_pathlib, fake_filesystem, fake_filesystem_unittest
-from pyfakefs.fake_filesystem import is_root
-from pyfakefs.helpers import IS_PYPY
+from pyfakefs import fake_pathlib, fake_filesystem, fake_filesystem_unittest, fake_os
+from pyfakefs.fake_filesystem import OSType
+from pyfakefs.helpers import IS_PYPY, is_root
 from pyfakefs.tests.test_utils import RealFsTestMixin
 
 is_windows = sys.platform == "win32"
@@ -203,8 +203,8 @@ class RealPathlibInitializationWithDriveTest(FakePathlibInitializationWithDriveT
 class FakePathlibPurePathTest(RealPathlibTestCase):
     """Tests functionality present in PurePath class."""
 
-    @unittest.skipIf(is_windows, "POSIX specific behavior")
     def test_is_reserved_posix(self):
+        self.check_posix_only()
         self.assertFalse(self.path("/dev").is_reserved())
         self.assertFalse(self.path("/").is_reserved())
         self.assertFalse(self.path("COM1").is_reserved())
@@ -402,7 +402,7 @@ class FakePathlibFileObjectPropertyTest(RealPathlibTestCase):
         self.skip_if_symlink_not_supported()
         file_stat = self.os.stat(self.file_path)
         link_stat = self.os.lstat(self.file_link_path)
-        if self.real_os.chmod not in os.supports_follow_symlinks or IS_PYPY:
+        if self.os.chmod not in self.os.supports_follow_symlinks or IS_PYPY:
             with self.assertRaises(NotImplementedError):
                 self.path(self.file_link_path).chmod(0o444, follow_symlinks=False)
         else:
@@ -762,7 +762,6 @@ class RealPathlibPathFileOperationTest(FakePathlibPathFileOperationTest):
         return True
 
 
-@unittest.skipIf(sys.version_info < (3, 6), "path-like objects new in Python 3.6")
 class FakePathlibUsageInOsFunctionsTest(RealPathlibTestCase):
     """Test that many os / os.path functions accept a path-like object
     since Python 3.6. The functionality of these functions is tested
@@ -1121,12 +1120,11 @@ class RealPathlibUsageInOsFunctionsTest(FakePathlibUsageInOsFunctionsTest):
         return True
 
 
-@unittest.skipIf(sys.version_info < (3, 6), "Path-like objects new in Python 3.6")
 class FakeFilesystemPathLikeObjectTest(unittest.TestCase):
     def setUp(self):
         self.filesystem = fake_filesystem.FakeFilesystem(path_separator="/")
         self.pathlib = fake_pathlib.FakePathlibModule(self.filesystem)
-        self.os = fake_filesystem.FakeOsModule(self.filesystem)
+        self.os = fake_os.FakeOsModule(self.filesystem)
 
     def test_create_dir_with_pathlib_path(self):
         dir_path_string = "foo/bar/baz"
@@ -1180,5 +1178,23 @@ class FakeFilesystemPathLikeObjectTest(unittest.TestCase):
         )
 
 
+class FakeFilesystemChmodTest(fake_filesystem_unittest.TestCase):
+    def setUp(self) -> None:
+        self.setUpPyfakefs()
+
+    @unittest.skipIf(sys.platform != "win32", "Windows specific test")
+    def test_is_file_for_unreadable_dir_windows(self):
+        self.fs.os = OSType.WINDOWS
+        path = pathlib.Path("/foo/bar")
+        self.fs.create_file(path)
+        # normal chmod does not really set the mode to 0
+        self.fs.chmod("/foo", 0o000)
+        self.assertTrue(path.is_file())
+        # but it does in forced UNIX mode
+        self.fs.chmod("/foo", 0o000, force_unix_mode=True)
+        with self.assertRaises(PermissionError):
+            path.is_file()
+
+
 if __name__ == "__main__":
     unittest.main(verbosity=2)
